<?xml version="1.0"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/1999/xhtml"
                version='1.0'>

<xsl:output method="xml" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" omit-xml-declaration="yes" indent="yes"/>

<xsl:template match="ddoc">
  <html>
    <head>
      <title>
        Module "<xsl:value-of select="title" />"
      </title>
      <link rel="stylesheet" type="text/css" href="style.css" />
    </head>
    <body>
      <h1>Module "<xsl:value-of select="title" />"</h1>
      <xsl:call-template name="module"/>
      
      <xsl:for-each select="body/members">
        <h2>Members:</h2>
        <xsl:call-template name="members"/>
      </xsl:for-each>
      
      <hr />
      <xsl:call-template name="details"/>

      <hr />
      <xsl:for-each select="body/members">
        <xsl:call-template name="memberdetails"/>
      </xsl:for-each>
    </body>
  </html>
</xsl:template>

<xsl:template name="module">
  <xsl:for-each select="body/sections/summary">
    <xsl:value-of select="." />
  </xsl:for-each>
  <br />
  <br />
  <table class="moduleinfo">
    <tbody>
      <xsl:for-each select="datetime">
        <tr>
          <td class="title">Built on:</td>
          <td><xsl:value-of select="." /></td>
        </tr>
      </xsl:for-each>
      <xsl:for-each select="copyright">
        <tr>
          <td class="title">Copyright:</td>
          <td><xsl:value-of select="." /></td>
        </tr>
      </xsl:for-each>
      <xsl:for-each select="body/sections/authors">
        <tr>
          <td class="title">Authors:</td>
          <td><xsl:value-of select="." /></td>
        </tr>
      </xsl:for-each>
      <xsl:for-each select="body/sections/license">
        <tr>
          <td class="title">License:</td>
          <td><xsl:value-of select="." /></td>
        </tr>
      </xsl:for-each>
      <xsl:for-each select="body/sections/standards">
        <tr>
          <td class="title">Standards:</td>
          <td><xsl:value-of select="." /></td>
        </tr>
      </xsl:for-each>
      <xsl:for-each select="body/sections/version">
        <tr>
          <td class="title">Version:</td>
          <td><xsl:value-of select="." /></td>
        </tr>
      </xsl:for-each>
    </tbody>
  </table>
</xsl:template>

<xsl:template name="members">
  <xsl:for-each select="declaration">
    <xsl:apply-templates />
    <br />
  </xsl:for-each>
</xsl:template>

<xsl:template name="details">
  <xsl:for-each select="body/sections/description">
    <h2>Detailed description:</h2>
    <xsl:value-of select="." />
    <br />
  </xsl:for-each>
  <xsl:for-each select="body/sections/examples">
    <h2>Examples:</h2>
    <xsl:value-of select="." />
    <br />
  </xsl:for-each>
  <xsl:for-each select="body/sections/history">
    <h2>Version history:</h2>
    <xsl:value-of select="." />
    <br />
  </xsl:for-each>
  <xsl:for-each select="body/sections/bugs">
    <h2>Bugs:</h2>
    <xsl:value-of select="." />
    <br />
  </xsl:for-each>
</xsl:template>

<xsl:template name="memberdetails">
  <xsl:for-each select="declaration">
    <span class="decltitle">
    <xsl:apply-templates />
    </span>
    <br />
    <xsl:for-each select="following-sibling::decldescription[1]">
      <xsl:for-each select="sections">
        <xsl:apply-templates />
      </xsl:for-each>
      <xsl:for-each select="members">
        <blockquote>
          <xsl:call-template name="memberdetails"/>
        </blockquote>
      </xsl:for-each>
    </xsl:for-each>
    <xsl:if test="following-sibling::declaration">
      <hr />
    </xsl:if>
  </xsl:for-each>
</xsl:template>

<xsl:template match="sections">
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="summary">
  <h3>Summary:</h3>
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="description">
  <h3>Description:</h3>
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="authors">
  <h3>Authors:</h3>
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="bugs">
  <h3>Bugs:</h3>
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="Date">
  <h3>date:</h3>
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="license">
  <h3>License:</h3>
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="standards">
  <h3>Standards:</h3>
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="version">
  <h3>Version:</h3>
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="history">
  <h3>History:</h3>
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="examples">
  <h3>Examples:</h3>
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="deprecated">
  <h3>Deprecated:</h3>
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="returns">
  <h3>Returns:</h3>
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="seealso">
  <h3>See also:</h3>
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="throws">
  <h3>Throws:</h3>
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="params">
  <h3>Parameters:</h3>
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="psymbol">
  <span class="psymbol">
    <xsl:apply-templates />
  </span>
</xsl:template>

<xsl:template match="param">
  <span class="param">
    <xsl:apply-templates />
  </span>
</xsl:template>

<xsl:template match="code">
  <pre><code>
    <xsl:apply-templates />
  </code></pre>
</xsl:template>

</xsl:stylesheet>
